from setuptools import setup, find_packages

setup(
    name="eman_student_tools_v1",  
    version="0.1",
    packages=find_packages(),
    description="A simple student utility library",
    author="Eman Mustafa",
    author_email="s2024332037@umt.edu.pk",
    install_requires=[], 
)